import React, { useState, useEffect } from "react";
import { Button } from "@/components/ui/button";
import { ArrowDownIcon, ShoppingBag } from "lucide-react";
import HeroImageRotator from "./HeroImageRotator";
import { useIsMobile } from "@/hooks/use-mobile";
import { useHeroBanners } from "@/hooks/useHeroBanners";
import { useActiveMobileBanners } from "@/hooks/useMobileBanners";
const Hero: React.FC = () => {
  const isMobile = useIsMobile();
  const [currentMobileImageIndex, setCurrentMobileImageIndex] = useState(0);
  const [heroText, setHeroText] = useState<{
    title: string;
    subtitle: string;
  }>({
    title: "HANDCRAFTED PIECES",
    subtitle: "THAT SPEAK YOUR STYLE"
  });

  // Fetch hero banners from Supabase
  const {
    data: heroBanners,
    isLoading: heroLoading,
    error: heroError
  } = useHeroBanners();

  // Fetch mobile banners from Supabase
  const {
    data: mobileBanners,
    isLoading: mobileLoading,
    error: mobileError
  } = useActiveMobileBanners();

  // Updated fallback images - desktop optimized (16:9 aspect ratio, 1920x1080 recommended)
  const fallbackHeroImages = ['/lovable-uploads/10aded25-c853-4bec-a7d9-750f3c91038a.png', '/lovable-uploads/d2ef4a4a-4ff1-45e4-b3d8-e87e0606b9e9.png', '/lovable-uploads/c9ba2e2c-0aef-413f-87b4-b3ec12fc2d79.png'];

  // Mobile optimized images (9:16 aspect ratio, 1080x1920 recommended)
  const fallbackMobileHeroImages = ['/lovable-uploads/20eeb0c5-e8b5-4e24-ae46-6676e935aa58.png', '/lovable-uploads/c2694c68-89d8-40c9-a2f7-df15f992ba14.png', '/lovable-uploads/a919d39a-94be-41ca-9bc1-bf0727f0aa6f.png'];

  // Filter active banners and use them if available
  const activeBanners = heroBanners?.filter(banner => banner.is_active) || [];
  const activeMobileBanners = mobileBanners || [];

  // Use dynamic banners if available, otherwise use fallback
  const heroImages = activeBanners.length > 0 ? activeBanners.map(banner => banner.desktop_image_url).filter(Boolean) : fallbackHeroImages;
  const mobileHeroImages = activeMobileBanners.length > 0 ? activeMobileBanners.map(banner => banner.image_url).filter(Boolean) : fallbackMobileHeroImages;

  // Hero text configurations for each mobile image
  const mobileHeroTexts = [{
    title: "HANDCRAFTED PIECES",
    subtitle: "THAT SPEAK YOUR STYLE"
  }, {
    title: "WHERE CULTURE",
    subtitle: "MEETS COUTURE"
  }, {
    title: "ETHNIC ELEGANCE",
    subtitle: "REDEFINED"
  }];
  const scrollToCollections = () => {
    const collectionsSection = document.getElementById("collections");
    if (collectionsSection) {
      collectionsSection.scrollIntoView({
        behavior: "smooth"
      });
    }
  };
  const handleMobileImageChange = (index: number) => {
    setCurrentMobileImageIndex(index);
    if (isMobile) {
      setHeroText(mobileHeroTexts[index] || mobileHeroTexts[0]);
    }
  };

  // Set initial text based on device type
  useEffect(() => {
    if (isMobile) {
      setHeroText(mobileHeroTexts[currentMobileImageIndex] || mobileHeroTexts[0]);
    } else {
      setHeroText({
        title: "HANDCRAFTED PIECES",
        subtitle: "THAT SPEAK YOUR STYLE"
      });
    }
  }, [isMobile, currentMobileImageIndex]);

  // Log for debugging
  useEffect(() => {
    console.log('Hero banners data:', heroBanners);
    console.log('Mobile banners data:', mobileBanners);
    console.log('Active banners:', activeBanners);
    console.log('Active mobile banners:', activeMobileBanners);
    console.log('Hero images:', heroImages);
    console.log('Mobile hero images:', mobileHeroImages);
  }, [heroBanners, mobileBanners, activeBanners, activeMobileBanners, heroImages, mobileHeroImages]);
  if (heroError) {
    console.error('Error fetching hero banners:', heroError);
  }
  if (mobileError) {
    console.error('Error fetching mobile banners:', mobileError);
  }
  return <section className="relative flex items-center justify-center overflow-hidden pt-20 w-full h-[85vh] md:h-[90vh] min-h-[550px] md:min-h-[600px]">
      {/* Hero Image Rotator */}
      <HeroImageRotator images={heroImages} mobileImages={mobileHeroImages} interval={5000} mobileInterval={2000} onImageChange={handleMobileImageChange} />
      
      {/* Content Overlay */}
      <div className="container mx-auto relative z-20 px-6 md:px-12">
        <div className="w-full flex justify-center">
          <div className="text-center max-w-4xl">
            {/* Hero Text */}
            <div className="mb-8">
              
              
            </div>

            {/* Call to Action Buttons */}
            <div className="flex flex-col sm:flex-row gap-4 justify-center items-center mb-8">
              
              
            </div>
          </div>
        </div>
      </div>
      
      {/* Gradient Overlay for better text readability */}
      <div className="absolute inset-0 bg-gradient-to-t from-black/40 via-transparent to-black/20 z-10"></div>
    </section>;
};
export default Hero;